@@ -21,7 +21,7 @@ class SerialDataSource(BytestreamDataSource):
     DEFAULT_PORT = "/dev/ttyUSB0"
     DEFAULT_BAUDRATE = 230400
 
-    def __init__(self, callback=None, port=None, baudrate=None):
+    def __init__(self, callback=None, port=None, baudrate=None, log_mode=None):
         """Initialize a connection to the serial device.
 
         Kwargs:
@@ -31,7 +31,7 @@ class SerialDataSource(BytestreamDataSource):
         Raises:
             DataSourceError if the serial device cannot be opened.
         """
-        super(SerialDataSource, self).__init__(callback)
+        super(SerialDataSource, self).__init__(callback, log_mode)
         port = port or self.DEFAULT_PORT
         baudrate = baudrate or self.DEFAULT_BAUDRATE
 
@@ -46,5 +46,5 @@ class SerialDataSource(BytestreamDataSource):
         else:
             LOG.debug("Opened serial device at %s", port)
 
-    def _read(self):
-        return self.device.readline()
+    def read(self):
+        return self.device.read()
